AppCategory enum

Category an app declares (Android 8.0 and above).

Inheritance
Available extensions

Values

game → const AppCategory
const AppCategory(0, "Game")
audio → const AppCategory
const AppCategory(1, "Audio")
video → const AppCategory
const AppCategory(2, "Video")
image → const AppCategory
const AppCategory(3, "Image")
social → const AppCategory
const AppCategory(4, "Social")
news → const AppCategory
const AppCategory(5, "News")
maps → const AppCategory
const AppCategory(6, "Maps")
productivity → const AppCategory
const AppCategory(7, "Productivity")
accessibility → const AppCategory
const AppCategory(8, "Accessibility")
undefined → const AppCategory
const AppCategory(-1, "Undefined")

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
Readable name.
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
Android ApplicationInfo.CATEGORY_* value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int? value) → AppCategory
Returns the category for an Android value, or undefined if unknown.

Constants

values → const List<AppCategory>
A constant List of the values in this enum, in order of their declaration.