PlatformType enum
Values
- flutter → const PlatformType
-
const PlatformType("flutter", "Flutter") - reactNative → const PlatformType
-
const PlatformType("react_native", "React Native") - xamarin → const PlatformType
-
const PlatformType("xamarin", "Xamarin") - ionic → const PlatformType
-
const PlatformType("ionic", "Ionic") - nativeOrOthers → const PlatformType
-
const PlatformType("native_or_others", "Native or Others")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String? raw) → PlatformType
Constants
-
values
→ const List<
PlatformType> - A constant List of the values in this enum, in order of their declaration.